{% if form.non_field_errors %}
    <div class="alert alert-danger">
        {% for error in form.non_field_errors %}
	    <div>{{ error }}</div>
	    {% endfor %}
    </div>
{% endif %}

{% for field in form.hidden_fields %}
    {{ field }}
{% endfor %}

{% for field in form.visible_fields %}
    {% include 'bootstrap/field.html' %}
{% endfor %}