{% load navigation static %}
<!DOCTYPE html>
<html lang="{{ LANGUAGE_CODE }}">
    <head>
        <meta charset="utf-8" />
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <meta name="viewport" content="width=device-width, initial-scale=1">
		<title>{% block title %}Django Manifest{% endblock %}</title>
		<meta name="keywords" content="{% block keywords %}django, manifest, framework, project{% endblock %}" />
		<meta name="description" content="{% block description %}A kickstarter for Django Web Framework projects.{% endblock %}" />
		<meta name="robots" content="{% block robots %}NOINDEX,NOFOLLOW{% endblock %}" />
		<link rel="shortcut icon" href="{% static 'favicon.ico' %}">
	    {% block stylesheet %}
		<link rel="stylesheet" type="text/css" media="screen" href="{% static 'css/bootstrap.min.css' %}?{% now 'U' %}" />
		<link rel="stylesheet" type="text/css" media="screen" href="{% static 'css/base.css' %}?{% now 'U' %}" />
    	{% endblock %}
        {% block headscript %}
        <!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
        <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
        <!--[if lt IE 9]>
            <script src="//cdnjs.cloudflare.com/ajax/libs/html5shiv/3.7.2/html5shiv.min.js"></script>
            <script src="//cdnjs.cloudflare.com/ajax/libs/respond.js/1.4.2/respond.min.js"></script>
        <![endif]-->
    	{% endblock %}
        {% block head %}{% endblock %}
    </head>
    <body class="{% block body_class %}base{% endblock %}">
    <!-- Navigation //-->
    {% block navbar_base %}
	    <nav class="navbar navbar-default navbar-fixed-top" role="navigation">
            <div class="container">
                {% block navbar %}
                <div class="navbar-header">
                    {% block navbar_header %}
                    <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#manifest-navbar-collapse">
                      <span class="sr-only">Toggle navigation</span>
                      <span class="icon-bar"></span>
                      <span class="icon-bar"></span>
                      <span class="icon-bar"></span>
                    </button>
        			<h1 id="brand"><a class="navbar-brand" href="/">Django Manifest</a></h1>
        			{% endblock %}
                </div>
                <div class="collapse navbar-collapse" id="manifest-navbar-collapse">
                    {% block navbar_collapse %}
                    <ul class="nav navbar-nav">
                        {% block navbar_nav %}
                        <li class="{% active '^/$' %}"><a href="/">{% trans "Home" %}</a></li>
                        <li class="{% active '^/about' %}"><a href="/about/">{% trans "About" %}</a></li>
                        <li class="{% active '^/contact' %}"><a href="/contact/">{% trans "Contact" %}</a></li>
                        {% endblock %}
                    </ul>
                    {% include "_navbar_search.html" %}
                    <div class="navbar-right">
                        {% include "_navbar_account.html" %}
                    </div>
                    {% endblock %}
                </div>
                {% endblock %}
            </div>
        </nav>
    {% endblock %}
    {% block messages %}
        {% if messages %}
        <!--// Messages -->
        <section id="messages" class="contianer">
            {% include "_messages.html" %}
        </section>
        {% endif %}
    {% endblock %}
    {% block content_base %}
    <!--// Content -->
        <section id="content" class="{% block content_class %}container{% endblock %}">
        {% block content %}{{ content }}{% endblock %}
        </section>
    {% endblock %}        
    {% block footer_base %}
    <!--// Footer -->
        <footer role="contentinfo">
        {% block footer %}
        <div class="container">
            <menu class="pull-right">
                <li><a href="#">{% trans "Help" %}</a></li>
                <li><a href="#">{% trans "Contact" %}</a></li>
            </menu>
            <p class="footer">Copyright 2012 &copy; Django Manifest</p>
        </div>
        {% endblock %}
        </footer>
    {% endblock %}        
    <!--// Tail -->
    {% block tail %}{% endblock %}
    {% block tailscript %}
	<script type="text/javascript" src="//cdnjs.cloudflare.com/ajax/libs/jquery/1.11.1/jquery.min.js"></script>
	<script type="text/javascript" src="{% static 'js/bootstrap.min.js'%}?{% now 'U' %}"></script>
	{% endblock %}
    </body>
</html>
