{% extends "base.html" %}
{% block title %}{% trans "Account not activated" %} - {{ block.super }}{% endblock %}
{% block content %}
<h2>{% trans "Account not activated" %}</h2>
<p>{% blocktrans %}It seems your {{ SITE_NAME }} website account has not been activated. You have to click on the link provided in the activation email which we have sent you.{% endblocktrans %}</p>
<p>{% trans "Feel free to contact us if you think something went wrong." %}</p>
{% endblock %} 
