{% extends 'base.html' %}
{% load i18n %}

{% block title %}{% trans "Sign In" %}{% endblock %}

{% block content %}
<form action="" method="post" class="form">
  {% csrf_token %}
  <fieldset>
    <legend>{% trans "Log in to your account" %}</legend>
    {{ form|bootstrap }}
  </fieldset>
  {% if next %}<input type="hidden" name="next" value="{{ next }}" />{% endif %}
 <div class="form-group">
     <input type="submit" value="{% trans "Log In" %}" class="btn btn-primary" />
     <a href="{% url 'accounts_password_reset' %}" title="{% trans "Forgot your password?" %}" class="btn">{% trans "Forgot your password?" %}</a>
 </div>
</form>
{% endblock %}
