{% extends 'base.html' %}
{% block title %}{% trans "Password has been set" %} - {{ block.super }}{% endblock %}
{% block content %}
<h2>{% trans "Password has been set" %}</h2>
{% url 'accounts_login' as login_url %}
<p>{% blocktrans %}Your password has been set. You can now <a href="{{ login_url }}">login</a> with your new password.{% endblocktrans %}</p>
{% endblock %}
