{{ formset.management_form }}

{% for form in formset %}

    {% if classes.label == 'sr-only' %}
    <div class="form-inline">
    {% endif %}

    {% include "bootstrapform/form.html" with form=form %}

    {% if classes.label == 'sr-only' %}
    </div>
    {% endif %}

{% endfor %}