{% extends "base.html" %}
{% block title %}{% trans "Internal server error" %}{% endblock %}
{% block content %}
    <p>{% trans "We're sorry but a server error has occurred. We've been notified and will look into it as soon as possible." %}</p>
{% endblock %}
