{% extends "base.html" %}
{% block title %}{% trans "Email address changed!" %} - {{ block.super }}{% endblock %}

{% block content %}
<h2 class="page-header">{% trans 'Email address changed!' %}</h2>
<p>{% blocktrans %}Your new email address is saved. You can continue using {{ SITE_NAME }} website with this email address.{% endblocktrans %}</p>
{% endblock %}
