{% extends "base.html" %}
{% block title %}{% trans "Email verification failed" %} - {{ block.super }}{% endblock %}
{% block content %}
<h2>{% trans "Email verification failed" %}</h2>
<p>{% trans "You could try changing it again in your account settings." %}</p>
<p>{% trans "Feel free to contact us if you think something went wrong." %}</p>
{% endblock %}
