{% extends "base.html" %}
{% load navigation %}
{% block body_class %}accounts{% endblock %}
{% block content %}
<div class="row">
    <article id="main" class="col-md-8">
        {% block main %}{% endblock %}
    </article>
    <aside id="side" class="col-md-4">
    {% block aside %}
        <h3>{% trans "Account" %}</h3>
        <ul class="nav nav-pills nav-stacked">
        {% if user.is_authenticated %}
            {% url 'accounts_profile_detail' user.username as profile_url %}
            <li class="{% active 'accounts_profile_detail' %}"><a href="{% url 'accounts_profile_detail' user.username %}"><span>{% trans 'View account' %}</span></a></li>
            <li class="{% active 'accounts_update' %}"><a href="{% url 'accounts_update' %}">{% trans "Edit profile" %}</a></li>
            <li class="{% active 'accounts_password_change' %}"><a href="{% url 'accounts_password_change' %}">{% trans "Change password" %}</a></li>
            <li class="{% active 'accounts_email_change' %}"><a href="{% url 'accounts_email_change' %}">{% trans "Change email address" %}</a></li>            
        {% endif %}
        </ul>
    {% endblock %}
    </aside>
</div>
{% endblock %}


