{% extends 'base.html' %}

{% block title %}{% trans "Logged out" %} - {{ block.super }}{% endblock %}

{% block content %}
<h2>{% trans "You have been logged out" %}</h2>
{% url 'accounts_login' as login_url %}
<p>{% blocktrans %}Click <a href="{{ login_url }}">here</a> to log in back.{% endblocktrans %}</p>
{% endblock %}
