{% extends "base.html" %}
{% block title %}{% trans "Account activation failed" %} - {{ block.super }}{% endblock %}
{% block content %}
<h2>{% trans "Account activation failed" %}</h2>
<p>{% blocktrans %}Your {{ SITE_NAME }} website account could not be activated. This could be because your activation link has aged. Please try registering again.{% endblocktrans %}</p>
<p>{% trans "Feel free to contact us if you think something went wrong." %}</p>
{% endblock %}
