{% extends "accounts/base.html" %}
{% block title %}{% trans "Change email address" %} - {{ block.super }}{% endblock %}

{% block main %}
<form action="" method="post" class="form">
  {% csrf_token %}
  <fieldset>
    <legend>{% trans "Change email address" %}</legend>
    {{ form|bootstrap }}
  </fieldset>
  <div class="form-group">
      <input type="submit" value="{% trans "Change email" %}" class="btn btn-primary" />    
  </div>
</form>
{% endblock %}
