{% block content %}
    <header class="comments">
        {% get_comment_count for object as comment_count %}
        <h3>{% ifequal comment_count 0 %}{% trans "No comment" %}{% else %}{% blocktrans count comment_count as counter %}Only <strong>one</strong> comment{% plural %}{{ counter }} comments{% endblocktrans %}{% endifequal %}</h3>
    </header>
    {% if perms.blogs.can_add_comment %}
    <menu class="comments">
    	<li class="add-comment"><a href="#comment_form">{% trans 'Write comment' %}</a></li>
    </menu>
    {% endif %}
    {% get_comment_list for object as comment_list %}
	{% include 'comments/comment_list.html' %}
    {% if user.is_authenticated %}    
    <div id="comment_form" class="comments">
    	<a name="comment_form"></a>
        {% include 'comments/comment_form.html' %}
    </div>
    {% endif %}
{% endblock %}
