{% extends 'base.html' %}

{% block title %}{% trans "Password reset" %} - {{ block.super }}{% endblock %}

{% block content %}
<form action="" method="post" class="form">
  {% csrf_token %}
  <fieldset>
    <legend>{% trans "Password reset" %}</legend>
    {{ form|bootstrap }}
  </fieldset>
  <div class="form-group">
  	<input type="submit" value="{% trans "Send password" %}" class="btn btn-primary" />
  </div>
</form>
{% endblock %}
