{% extends 'accounts/base.html' %}
{% block title %}{% blocktrans with user.username as username %}{{ username }}'s profile.{% endblocktrans %}{% endblock %}

{% block main %}
  <div class="white-box">
    <div id="details">
      {% block profile_details %}
      <img src="{{ user.avatar }}" width="128" height="128" alt="{{ user }}" />      
        <dl>
          {% block profile_definition_list %}
            {% if user.get_full_name %}
              <dt>{% trans "Name" %}</dt>
              <dd>{{ user.get_full_name }}</dd>
            {% endif %}
            {% if user.age %}          
              <dt>{% trans "Age" %}</dt>
              <dd>{{ user.age }}</dd>
            {% endif %}
            {% if user.website %}
              <dt>{% trans "website" %}</dt>
              <dd>{{ user.website|urlize }}</dd>
            {% endif %}
            {% if user.location %}
              <dt>{% trans "Location" %}</dt>
              <dd>{{ user.location }}</dd>
            {% endif %}
            {% if user.about_me %}
              <dt>{% trans "About me" %}</dt>
              <dd>{{ user.about_me }}</dd>
            {% endif %}
          {% endblock %}
        </dl>
      {% endblock %}
    </div>
  </div>
{% endblock %}
